# Testbench Tuna

[![pypi package](https://badge.fury.io/py/testbench-tuna.svg)](https://pypi.python.org/pypi/testbench-tuna/)
[![python](https://img.shields.io/pypi/pyversions/testbench-tuna.svg)](https://pypi.python.org/pypi/testbench-tuna)
[![downloads](https://pepy.tech/badge/testbench-tuna)](https://pepy.tech/project/testbench-tuna)
[![codecov](https://codecov.io/gh/trallnag/testbench-tuna/branch/trunk/graph/badge.svg?token=400YFJSVG7)](https://codecov.io/gh/trallnag/testbench-tuna)

Personal testbench where I try out things.

- <https://github.com/googleapis/release-please>
- <https://github.com/google-github-actions/release-please-action>
